-- Version 1.1 Fix: Added the "claims" handle and the "flag has returned to its base" handle.
-- Version 1.2 Fix: The slash command for the options is now "/bgsalerts".
-- Version 1.3 : Compatible with 1.10
-- Version 1.4 : Added AV announcements
-- Version 1.5 : Fixed AB events bug. New UI. AV options now available.
-- Version 1.7 : Implemented the new incoming alerts


WOW_DEF_DIR = "Interface\\AddOns\\BGSoundAlerts\\";
local CURRENT_PATCH_VERSION = 1.9;
local NEW_VERSION_ALERT = 0;

function BGSoundAlerts_Load()

	UIPanelWindows["BGSoundAlertsMainFrame"] = { area = "left", pushable = 1 };
	UIPanelWindows["BGSoundAlertsPatchNotes"] = { area = "left", pushable = 0 };
	
	this:RegisterEvent("CHAT_MSG_BG_SYSTEM_ALLIANCE");
	this:RegisterEvent("CHAT_MSG_BG_SYSTEM_HORDE");
	this:RegisterEvent("CHAT_MSG_BG_SYSTEM_NEUTRAL");
	this:RegisterEvent("CHAT_MSG_BATTLEGROUND");
	this:RegisterEvent("CHAT_MSG_BATTLEGROUND_LEADER");
	this:RegisterEvent("CHAT_MSG_RAID");
	this:RegisterEvent("CHAT_MSG_RAID_LEADER");
	this:RegisterEvent("CHAT_MSG_RAID_WARNING");
	this:RegisterEvent("CHAT_MSG_YELL");
	this:RegisterEvent("CHAT_MSG_MONSTER_YELL");
	this:RegisterEvent("CHAT_MSG_ADDON");
	this:RegisterEvent("VARIABLES_LOADED");
	
	StaticPopupDialogs["BGSOUNDALERTS_NEWVERSION"] = {
		text = TEXT("BGSoundAlerts Version "  .. CURRENT_PATCH_VERSION .. " installed!"),
		button1 = TEXT("See Patch Notes"),
		button2 = TEXT("Close"),
		OnAccept = BGSoundAlerts_ShowPatchNotes,
		timeout = 60
	};
	
	SlashCmdList["BG_ALERTS"] = BGSoundAlerts_ShowUI;
	SLASH_BG_ALERTS1 = "/bgsalerts";

end

function BGSoundAlerts_ShowUI(cmd)
	BGSoundAlertsMainFrame_Text:SetText("BGSoundAlerts By Klishu");
	SetPortraitTexture(BGSoundAlertsMainFrame_Portrait,"player");	

	ShowUIPanel(BGSoundAlertsMainFrame);
end

function BGSoundAlerts_Event(eventType,chatMsg,chatAuthor,extraArg)

	if (eventType == "CHAT_MSG_BG_SYSTEM_ALLIANCE") then
		BGSoundAlerts_AllianceSound(chatMsg);
		return;
	end
		
	if (eventType == "CHAT_MSG_BG_SYSTEM_HORDE") then
		BGSoundAlerts_HordeSound(chatMsg);
		return;
	end
	
	if (eventType == "CHAT_MSG_BG_SYSTEM_NEUTRAL") then
		BGSoundAlerts_NeutralSound(chatMsg);
		return;
	end

	if (eventType == "CHAT_MSG_YELL" or eventType == "CHAT_MSG_MONSTER_YELL") then
		BGSoundAlerts_AVSound(chatMsg,chatAuthor);
		return;
	end
	
	if (eventType == "VARIABLES_LOADED") then
		BGSoundAlerts_Initiate();
		-- Check with your guild mates and your current raid or party for new versions of BGSoundAlerts
		BGSoundAlerts_CheckForNewVersion("GUILD");
		BGSoundAlerts_CheckForNewVersion("RAID");
		return;
	end
	
	if (eventType == "CHAT_MSG_BATTLEGROUND" or eventType == "CHAT_MSG_BATTLEGROUND_LEADER" or
		eventType == "CHAT_MSG_RAID_WARNING" or eventType == "CHAT_MSG_RAID" or
		eventType == "CHAT_MSG_RAID_LEADER") then
		BGSoundAlerts_IncomingSound(chatMsg);
	end
	
	if (eventType == "CHAT_MSG_ADDON" and chatMsg == "BGSAlertsVersion"
		and chatAuthor == "VersionCheck") then
		BGSoundAlerts_SendVersion(extraArg);
	end
	
	if (eventType == "CHAT_MSG_ADDON" and chatMsg == "BGSAlertsVersion"
	    and tonumber(chatAuthor)) then
		-- Received a version number
		BGSoundAlerts_CompareVersion(chatAuthor);
	end
	
	if (eventType == "UPDATE_WORLD_STATES") then
		-- Check for new BGSoundAlerts version with the rest of the battleground
		BGSoundAlerts_CheckForNewVersion("BATTLEGROUND");
	end
		
	
end

function BGSoundAlerts_CheckForNewVersion(checkDest)
	
	-- Send a message to checkDest to request BGSoundAlerts version number
	SendAddonMessage("BGSAlertsVersion","VersionCheck",checkDest);
	
end

function BGSoundAlerts_SendVersion(checkDest)
	
	-- Send our version number
	SendAddonMessage("BGSAlertsVersion",CURRENT_PATCH_VERSION,checkDest);
	
end

function BGSoundAlerts_CompareVersion(number)
	
	-- Compare our version with the received one
	if (NEW_VERSION_ALERT == 0 and tonumber(number) > CURRENT_PATCH_VERSION) then
		UIErrorsFrame:AddMessage("New BGSoundAlerts out (Version " .. number .. ") is out.|nGo to http://ui.worldofwar.net/ to get the latest one!",1,1,0,10);
		NEW_VERSION_ALERT = 1;
	end
	
end

function BGSoundAlerts_Initiate()
	
	DEFAULT_CHAT_FRAME:AddMessage("BGSoundAlerts Loaded. Type /bgsalerts to choose what sounds you hear. Thanks to AlphaShade for the sounds.",0.0,1.0,0.0,1.0);
	
	if (WSGEvents == nil) then
		WSGEvents = 1;
	end
	
	if (WSGScore == nil) then
		WSGScore = 1;
	end
	
	if (ABEvents == nil) then
		ABEvents = 1;
	end
	
	if (ABScore == nil) then
		ABScore = 1;
	end
	
	if (ABScoreDelay == nil) then
		ABScoreDelay = 5;
	end
	
	if (AVMainEvents == nil) then
		AVMainEvents = 1;
	end
	
	if (AVExtraEvents == nil) then
		AVExtraEvents = 1;
	end
	
	if (SoundsPack == nil) then
		SoundsPack = "DefaultPack";
	end
	
	if (VictoryDefeatSounds == nil) then
		VictoryDefeatSounds = 1;
	end
	
	if (IncomingSounds == nil) then
		IncomingSounds = 1;
	end
	
	-- I'm not sure this works
	if (BGSoundAlerts_PatchVersion == nil or BGSoundAlerts_PatchVersion < CURRENT_PATCH_VERSION) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. "\\NewPatchInstalled.wav");
		BGSoundAlerts_PatchVersion = CURRENT_PATCH_VERSION;
		StaticPopup_Show("BGSOUNDALERTS_NEWVERSION");
	end
			
end

function BGSoundAlerts_InitiateOpp()
	-- This function will check if any checkboxes are unchecked and set the vars to 0 rather than nil
	if (WSGEvents == nil) then
		WSGEvents = 0;
	end
	
	if (WSGScore == nil) then
		WSGScore = 0;
	end
	
	if (ABEvents == nil) then
		ABEvents = 0;
	end
	
	if (ABScoreDelay == nil) then
		ABScoreDelay = 0;
	end
	
	if (AVMainEvents == nil) then
		AVMainEvents = 0;
	end
	
	if (AVExtraEvents == nil) then
		AVExtraEvents = 0;
	end
	
	if (VictoryDefeatSounds == nil) then
		VictoryDefeatSounds = 0;
	end
	
	if (IncomingSounds == nil) then
		IncomingSounds = 0;
	end
	
end

function BGSoundAlerts_Show()

	WSGSoundScore_Check:SetChecked(WSGScore);
	WSGSoundEvents_Check:SetChecked(WSGEvents);
	ABSoundEvents_Check:SetChecked(ABEvents);
	ABSoundScore_Check:SetChecked(ABScore);
	BGSoundAlerts_ABScoreInterval:SetText(ABScoreDelay);
	AVSoundMainEvents_Check:SetChecked(AVMainEvents);
	AVSoundExtraEvents_Check:SetChecked(AVExtraEvents);
	VictoryDefeatSounds_Check:SetChecked(VictoryDefeatSounds);
	IncomingSounds_Check:SetChecked(IncomingSounds);
	BGSoundAlerts_PackName:SetText(SoundsPack);
	
end

function BGSoundAlerts_Accept()
	
	WSGScore = WSGSoundScore_Check:GetChecked();
	WSGEvents = WSGSoundEvents_Check:GetChecked();
	ABEvents = ABSoundEvents_Check:GetChecked();
	ABScore = ABSoundScore_Check:GetChecked();
	-- Check if it's a number. Show error and options panel again if not
	if (tonumber(BGSoundAlerts_ABScoreInterval:GetText()) >= 1) then
		ABScoreDelay = tonumber(BGSoundAlerts_ABScoreInterval:GetText());
	else
		UIErrorsFrame:AddMessage("Invalid Number Entry. Please enter the ABScoreDelay time again.");
		ShowUIPanel(BGSoundAlertsMainFrame);
	end
	AVMainEvents = AVSoundMainEvents_Check:GetChecked();
	AVExtraEvents = AVSoundExtraEvents_Check:GetChecked();
	VictoryDefeatSounds = VictoryDefeatSounds_Check:GetChecked();
	IncomingSounds = IncomingSounds_Check:GetChecked();
	SoundsPack = BGSoundAlerts_PackName:GetText();
	
	-- Check for nils
	BGSoundAlerts_InitiateOpp();
	
end
	
function BGSoundAlerts_AllianceSound(msg)

	if (string.find(msg,"The Alliance Flag was returned") ~= nil and WSGEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceFlagReturned.wav");
		return;
	end
	
	if (string.find(msg,"The Horde flag was picked up") ~= nil and WSGEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeFlagTaken.wav");
		return;
	end
	
	_, AllianceScore = GetWorldStateUIInfo(1);
	
	if (string.find(msg,"captured the Horde flag") ~= nil and WSGEvents == 1 and AllianceScore ~= "3/3") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeFlagCaptured.wav");
		return;
	end
	
	if (string.find(msg,"assaulted the stables") ~= nil and ABEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceAssaultedStables.wav");
		return;
	end
	
	if (string.find(msg,"assaulted the lumber") ~= nil and ABEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceAssaultedLumbermill.wav");
		return;
	end
	
	if (string.find(msg,"assaulted the blacksmith") ~= nil and ABEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceAssaultedBlacksmith.wav");
		return;
	end
	
	if (string.find(msg,"assaulted the mine") ~= nil and ABEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceAssaultedGoldMine.wav");
		return;
	end
	
	if (string.find(msg,"assaulted the farm") ~= nil and ABEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceAssaultedFarm.wav");
		return;
	end
	
	if (string.find(msg,"taken the stables") ~= nil and ABEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceTakenStables.wav");
		return;
	end
	
	if (string.find(msg,"taken the lumber") ~= nil and ABEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceTakenLumbermill.wav");
		return;
	end
	
	if (string.find(msg,"taken the blacksmith") ~= nil and ABEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceTakenBlacksmith.wav");
		return;
	end
	
	if (string.find(msg,"taken the mine") ~= nil and ABEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceTakenGoldMine.wav");
		return;
	end
	
	if (string.find(msg,"taken the farm") ~= nil and ABEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceTakenFarm.wav");
		return;
	end
	
	if (string.find(msg,"claims the lumber") ~= nil and ABEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceAssaultedLumbermill.wav");
		return;
	end
	
	if (string.find(msg,"claims the blacksmith") ~= nil and ABEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceAssaultedBlacksmith.wav");
		return;
	end
	
	if (string.find(msg,"claims the mine") ~= nil and ABEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceAssaultedGoldMine.wav");
		return;
	end
	
	if (string.find(msg,"claims the farm") ~= nil and ABEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceAssaultedFarm.wav");
		return;
	end
	
	if (string.find(msg,"claims the stables") ~= nil and ABEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceAssaultedStables.wav");
		return;
	end
	
	if (string.find(msg,"wins") ~= nil) then
		BGSoundAlerts_ClearSoundQueue();
		BGSoundAlerts_EndGameSound(msg);
	end
end

function BGSoundAlerts_HordeSound(msg)

	if (string.find(msg,"The Horde flag was returned") ~= nil and WSGEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeFlagReturned.wav");
		return;
	end
	
	if (string.find(msg,"The Alliance Flag was picked up") ~= nil and WSGEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceFlagTaken.wav");
		return;
	end
	
	_, HordeScore = GetWorldStateUIInfo(2);
	
	if (string.find(msg,"captured the Alliance flag") ~= nil and WSGEvents == 1 and HordeScore ~= "3/3") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceFlagCaptured.wav");
		return;
	end
	
	if (string.find(msg,"assaulted the stables") ~= nil and ABEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeAssaultedStables.wav");
		return;
	end
	
	if (string.find(msg,"assaulted the lumber") ~= nil and ABEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeAssaultedLumbermill.wav");
		return;
	end
	
	if (string.find(msg,"assaulted the blacksmith") ~= nil and ABEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeAssaultedBlacksmith.wav");
		return;
	end
	
	if (string.find(msg,"assaulted the mine") ~= nil and ABEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeAssaultedGoldMine.wav");
		return;
	end
	
	if (string.find(msg,"assaulted the farm") ~= nil and ABEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeAssaultedFarm.wav");
		return;
	end
	
	if (string.find(msg,"taken the stables") ~= nil and ABEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeTakenStables.wav");
		return;
	end
	
	if (string.find(msg,"taken the lumber") ~= nil and ABEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeTakenLumbermill.wav");
		return;
	end
	
	if (string.find(msg,"taken the blacksmith") ~= nil and ABEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeTakenBlacksmith.wav");
		return;
	end
	
	if (string.find(msg,"taken the mine") ~= nil and ABEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeTakenGoldMine.wav");
		return;
	end
	
	if (string.find(msg,"taken the farm") ~= nil and ABEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeTakenFarm.wav");
		return;
	end
	
	if (string.find(msg,"claims the stables") ~= nil and ABEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeAssaultedStables.wav");
		return;
	end
	
	if (string.find(msg,"claims the lumber") ~= nil and ABEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeAssaultedLumbermill.wav");
		return;
	end
	
	if (string.find(msg,"claims the blacksmith") ~= nil and ABEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeAssaultedBlacksmith.wav");
		return;
	end
	
	if (string.find(msg,"claims the mine") ~= nil and ABEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeAssaultedGoldMine.wav");
		return;
	end
	
	if (string.find(msg,"claims the farm") ~= nil and ABEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeAssaultedFarm.wav");
		return;
	end

	if (string.find(msg,"wins") ~= nil) then
		BGSoundAlerts_ClearSoundQueue();
		BGSoundAlerts_EndGameSound(msg);
	end
	
end

function BGSoundAlerts_NeutralSound(msg)

	if(string.find(msg,"placed at their bases") ~= nil and WSGScore == 1) then
		BGSounds_ScoreSound();
		return;
	end
	
	if (string.find(msg,"The Horde flag has returned") ~= nil and WSGEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeFlagReturned.wav");
		return;
	end
	
	if (string.find(msg,"The Alliance Flag has returned") ~= nil and WSGEvents == 1) then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceFlagReturned.wav");
		return;
	end
	
	if (string.find(msg,"wins") ~= nil) then
		BGSoundAlerts_EndGameSound(msg);
	end
	
end

-- The following is the very BIG list of events that happen in AV
function BGSoundAlerts_AVSound(chatMsg,chatAuthor)
	
	if (AVMainEvents == 1) then
	-- Alliance Assaulted Graveyards
	if (string.find(chatMsg,"Iceblood Graveyard is under attack!  If left unchecked, the Alliance") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceAssaultedIcebloodGraveyard.wav");
		return;
	end
	
	if (string.find(chatMsg,"Stonehearth Graveyard is under attack!  If left unchecked, the Alliance") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceAssaultedStonehearthGraveyard.wav");
		return;
	end
	
	if (string.find(chatMsg,"Snowfall Graveyard is under attack!  If left unchecked, the Alliance") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceAssaultedSnowfallGraveyard.wav");
		return;
	end
	
	if (string.find(chatMsg,"Frostwolf Graveyard is under attack!  If left unchecked, the Alliance") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceAssaultedFrostwolfGraveyard.wav");
		return;
	end
	
	if (string.find(chatMsg,"Stormpike Graveyard is under attack!  If left unchecked, the Alliance") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceAssaultedStormpikeGraveyard.wav");
		return;
	end
	
	if (string.find(chatMsg,"Frostwolf Relief Hut is under attack!  If left unchecked, the Alliance") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceAssaultedFrostwolfAidStation.wav");
		return;
	end
	
	if (string.find(chatMsg,"Stormpike Aid Station is under attack!  If left unchecked, the Alliance") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceAssaultedStormpikeAidStation.wav");
		return;
	end

	-- Alliance taken Graveyards
	if (string.find(chatMsg,"Iceblood Graveyard was taken by the Alliance") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceTakenIcebloodGraveyard.wav");
		return;
	end
	
	if (string.find(chatMsg,"Stonehearth Graveyard was taken by the Alliance") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceTakenStonehearthGraveyard.wav");
		return;
	end
	
	if (string.find(chatMsg,"Snowfall Graveyard was taken by the Alliance") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceTakenSnowfallGraveyard.wav");
		return;
	end
	
	if (string.find(chatMsg,"Frostwolf Graveyard was taken by the Alliance") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceTakenFrostwolfGraveyard.wav");
		return;
	end
	
	if (string.find(chatMsg,"Stormpike Graveyard was taken by the Alliance") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceTakenStormpikeGraveyard.wav");
		return;
	end
	
	if (string.find(chatMsg,"Frostwolf Relief Hut was taken by the Alliance") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceTakenFrostwolfAidStation.wav");
		return;
	end
	
	if (string.find(chatMsg,"Stormpike Aid Station was taken by the Alliance") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceTakenStormpikeAidStation.wav");
		return;
	end
	
	-- Horde Assaulted Graveyards
	if (string.find(chatMsg,"Iceblood Graveyard is under attack!  If left unchecked, the Horde") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeAssaultedIcebloodGraveyard.wav");
		return;
	end
	
	if (string.find(chatMsg,"Stonehearth Graveyard is under attack!  If left unchecked, the Horde") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeAssaultedStonehearthGraveyard.wav");
		return;
	end
	
	if (string.find(chatMsg,"Snowfall Graveyard is under attack!  If left unchecked, the Horde") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeAssaultedSnowfallGraveyard.wav");
		return;
	end
	
	if (string.find(chatMsg,"Frostwolf Graveyard is under attack!  If left unchecked, the Horde") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeAssaultedFrostwolfGraveyard.wav");
		return;
	end
	
	if (string.find(chatMsg,"Stormpike Graveyard is under attack!  If left unchecked, the Horde") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeAssaultedStormpikeGraveyard.wav");
		return;
	end
	
	if (string.find(chatMsg,"Frostwolf Relief Hut is under attack!  If left unchecked, the Horde") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeAssaultedFrostwolfAidStation.wav");
		return;
	end
	
	if (string.find(chatMsg,"Stormpike Aid Station is under attack!  If left unchecked, the Horde") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeAssaultedStormpikeAidStation.wav");
		return;
	end

	-- Horde taken Graveyards
	if (string.find(chatMsg,"Iceblood Graveyard was taken by the Horde") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeTakenIcebloodGraveyard.wav");
		return;
	end
	
	if (string.find(chatMsg,"Stonehearth Graveyard was taken by the Horde") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeTakenStonehearthGraveyard.wav");
		return;
	end
	
	if (string.find(chatMsg,"Snowfall Graveyard was taken by the Horde") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeTakenSnowfallGraveyard.wav");
		return;
	end
	
	if (string.find(chatMsg,"Frostwolf Graveyard was taken by the Horde") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeTakenFrostwolfGraveyard.wav");
		return;
	end
	
	if (string.find(chatMsg,"Stormpike Graveyard was taken by the Horde") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeTakenStormpikeGraveyard.wav");
		return;
	end
	
	if (string.find(chatMsg,"Frostwolf Relief Hut was taken by the Horde") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeTakenFrostwolfAidStation.wav");
		return;
	end
	
	if (string.find(chatMsg,"Stormpike Aid Station was taken by the Horde") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeTakenStormpikeAidStation.wav");
		return;
	end
	
	-- Towers Assaulted
	if (string.find(chatMsg,"Stonehearth Bunker is under attack!  If left unchecked, the Horde") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\StonehearthBunkerAssaulted.wav");
		return;
	end
	
	if (string.find(chatMsg,"Icewing Bunker is under attack!  If left unchecked, the Horde") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\IcewingBunkerAssaulted.wav");
		return;
	end
	
	if (string.find(chatMsg,"South Bunker is under attack!  If left unchecked, the Horde") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\DunBalderSouthBunkerAssaulted.wav");
		return;
	end
	
	if (string.find(chatMsg,"North Bunker is under attack!  If left unchecked, the Horde") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\DunBalderNorthBunkerAssaulted.wav");
		return;
	end
	
	if (string.find(chatMsg,"Iceblood Tower is under attack!  If left unchecked, the Alliance") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\IcebloodTowerAssaulted.wav");
		return;
	end
	
	if (string.find(chatMsg,"Tower Point is under attack!  If left unchecked, the Alliance") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\TowerPointAssaulted.wav");
		return;
	end
	
	if (string.find(chatMsg,"West Frostwolf Tower is under attack!  If left unchecked, the Alliance") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\WestFrostwolfTowerAssaulted.wav");
		return;
	end
	
	if (string.find(chatMsg,"East Frostwolf Tower is under attack!  If left unchecked, the Alliance") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\EastFrostwolfTowerAssaulted.wav");
		return;
	end
	
	-- Towers Taken
	if (string.find(chatMsg,"Stonehearth Bunker was taken by the Alliance") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\StonehearthBunkerTaken.wav");
		return;
	end
	
	if (string.find(chatMsg,"Icewing Bunker was taken by the Alliance") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\IcewingBunkerTaken.wav");
		return;
	end
	
	if (string.find(chatMsg,"South Bunker was taken by the Alliance") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\DunBalderSouthBunkerTaken.wav");
		return;
	end
	
	if (string.find(chatMsg,"North Bunker was taken by the Alliance") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\DunBalderNorthBunkerTaken.wav");
		return;
	end
	
	if (string.find(chatMsg,"Iceblood Tower was taken by the Horde") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\IcebloodTowerTaken.wav");
		return;
	end
	
	if (string.find(chatMsg,"Tower Point was taken by the Horde") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\TowerPointTaken.wav");
		return;
	end
	
	if (string.find(chatMsg,"West Frostwolf Tower was taken by the Horde") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\WestFrostwolfTowerTaken.wav");
		return;
	end
	
	if (string.find(chatMsg,"East Frostwolf Tower was taken by the Horde") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\EastFrostwolfTowerTaken.wav");
		return;
	end
	
	-- Towers destroyed
	if (string.find(chatMsg,"Stonehearth Bunker was destroyed by the Horde") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\StonehearthBunkerDestroyed.wav");
		return;
	end
	
	if (string.find(chatMsg,"Icewing Bunker was destroyed by the Horde") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\IcewingBunkerDestroyed.wav");
		return;
	end
	
	if (string.find(chatMsg,"South Bunker was destroyed by the Horde") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\DunBalderSouthBunkerDestroyed.wav");
		return;
	end
	
	if (string.find(chatMsg,"North Bunker was destroyed by the Horde") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\DunBalderNorthBunkerDestroyed.wav");
		return;
	end
	
	if (string.find(chatMsg,"Iceblood Tower was destroyed by the Alliance") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\IcebloodTowerDestroyed.wav");
		return;
	end
	
	if (string.find(chatMsg,"Tower Point was destroyed by the Alliance") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\TowerPointDestroyed.wav");
		return;
	end
	
	if (string.find(chatMsg,"West Frostwolf Tower was destroyed by the Alliance") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\WestFrostwolfTowerDestroyed.wav");
		return;
	end
	
	if (string.find(chatMsg,"East Frostwolf Tower was destroyed by the Alliance") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\EastFrostwolfTowerDestroyed.wav");
		return;
	end
	
	-- Gold Mines
	if (string.find(chatMsg,"Horde has taken the Coldtooth Mine") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeTakenColdtoothMine.wav");
		return;
	end
	
	if (string.find(chatMsg,"Alliance has taken the Coldtooth Mine") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceTakenColdtoothMine.wav");
		return;
	end
	
	if (string.find(chatMsg,"Snivvle") ~= nil and chatAuthor == "Taskmaster Snivvle") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\NeutralTakenColdtoothMine.wav");
		return;
	end
	
	if (string.find(chatMsg,"Horde has taken the Irondeep Mine") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeTakenIrondeepMine.wav");
		return;
	end
	
	if (string.find(chatMsg,"Alliance has taken the Irondeep Mine") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceTakenIrondeepMine.wav");
		return;
	end
	
	if (string.find(chatMsg,"MINE") ~= nil and chatAuthor == "Morloch") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\NeutralTakenIrondeepMine.wav");
		return;
	end
	end
	
	if (AVExtraEvents == 1) then
	-- Alliance Ram Riders
	if (chatAuthor == "Stormpike Ram Rider Commander") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceLaunchingRamRiders.wav");
		return;
	end
	
	-- Horde Frostwolf Riders
	if (chatAuthor == "Frostwolf Rider Commander") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeLaunchingFrostwolfRiders.wav");
		return;
	end
	
	-- Captains under attack
	if (string.find(chatMsg,"Die!  Your kind has no place in Alterac Valley") ~= nil and chatAuthor == "Captain Galvangar") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\CaptianGalvangarUnderAttack.wav");
		return;
	end
	
	-- Can't remember whole phrase
	if (string.find(chatMsg,"scum") ~= nil and chatAuthor == "Captain Balinda Stonehearth") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\CaptainBalindaStonehearthUnderAttack.wav");
		return;
	end
	
	-- Unit Upgrades
	if (chatAuthor == "Murgot Deepforge") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceUpgradingUnits.wav");
		return;
	end
	
	if (chatAuthor == "Smith Regzar") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeUpgradingUnits.wav");
		return;
	end

	-- Generals under attack
	if (string.find(chatMsg,"filth") ~= nil and chatAuthor == "Drek'Thar") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeGeneralUnderAttack.wav");
		return;
	end

	if (string.find(chatMsg,"I require aid") ~= nil and chatAuthor == "Vanndar Stormpike") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceGeneralUnderAttack.wav");
		return;
	end
	
	-- Horde Launching Air Support
	if (string.find(chatMsg,"is joining the battle") ~= nil and chatAuthor == "Wing Commander Guse") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeAirLaunching.wav");
		return;
	end
	
	if (string.find(chatMsg,"coming for you") ~= nil and chatAuthor == "Wing Commander Jeztor") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeAirLaunching.wav");
		return;
	end
	
	-- Alliance Launching Air Support
	if (string.find(chatMsg,"feel the flames") ~= nil and chatAuthor == "Wing Commander Sildore") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceAirLaunching.wav");
		return;
	end
	
	
	if (string.find(chatMsg,"for a swift death") ~= nil and chatAuthor == "Wing Commander Vipore") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceAirLaunching.wav");
		return;
	end
	
	-- Launching Ulimate Unit
	if (string.find(chatMsg,"wicked") ~= nil and chatAuthor == "Ivus the Forest Lord") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\AllianceLaunchingUltimateUnit.wav");
		return;
	end

	if (string.find(chatMsg,"It is done") ~= nil and chatAuthor == "Primalist Thurloga") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\HordeLaunchingUltimateUnit.wav");
		return;
	end
	end
	
	-- Win message
	if (string.find(chatMsg,"win") ~= nil and chatAuthor == "Herald") then
		BGSoundAlerts_ClearSoundQueue();
		BGSoundAlerts_EndGameSound(chatMsg);
		return;
	end
end
	
function BGSounds_ScoreSound()

	local _,AllianceScore = GetWorldStateUIInfo(1);
	local _HordeScore = GetWorldStateUIInfo(2);
	
	if (AllianceScore == "0/3" and HordeScore == "0/3") then
		-- Do not play a sound as this is the start of the game
		return;
	end
	
	if (AllianceScore == "0/3" and HordeScore == "1/3") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\Alliance0Horde1.wav");
		return;
	end
	
	if (AllianceScore == "0/3" and HordeScore == "2/3") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\Alliance0Horde2.wav");
		return;
	end
	
	if (AllianceScore == "1/3" and HordeScore == "0/3") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\Alliance1Horde0.wav");
		return;
	end
	
	if (AllianceScore == "1/3" and HordeScore == "1/3") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\Alliance1Horde1.wav");
		return;
	end

	if (AllianceScore == "1/3" and HordeScore == "2/3") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\Alliance1Horde2.wav");
		return;
	end
	
	if (AllianceScore == "2/3" and HordeScore == "0/3") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\Alliance2Horde0.wav");
		return;
	end
	
	if (AllianceScore == "2/3" and HordeScore == "1/3") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\Alliance2Horde1.wav");
		return;
	end
	
	if (AllianceScore == "2/3" and HordeScore == "2/3") then
		BGSoundAlerts_AddToQueue(WOW_DEF_DIR .. SoundsPack .. "\\Alliance2Horde2.wav");
		return;
	end
	
end

function BGSoundAlerts_ShowHelpTooltip(helpstring)
	
	if (helpstring) then
		GameTooltip:ClearLines();
		GameTooltip:SetOwner(this,"ANCHOR_RIGHT");
		GameTooltip:AddLine(helpstring);		
		GameTooltip:Show();
	end
	
end

function BGSoundAlerts_HideHelpTooltip()
	GameTooltip:Hide();
end

-- This function will check the end game winner
function BGSoundAlerts_PlayerWon(msg)
	local PlayerRace = UnitFactionGroup("player");
	
	-- DEFAULT_CHAT_FRAME:AddMessage("PlayerWon?");
		
	if (string.find(msg,"Horde") and PlayerRace == "Horde") then
	--	DEFAULT_CHAT_FRAME:AddMessage("WIN")
		return 1;
	end
		
	if (string.find(msg,"Alliance") and PlayerRace == "Alliance") then
		return 1;
	end
		
	return nil;
	
 end
  
 -- This function will  return the intensity of a win or loss
 function BGSoundAlerts_EndGameIntensity()
	
	-- DEFAULT_CHAT_FRAME:AddMessage("EndGameIntensity");
	
	local _,AllianceScore = GetWorldStateUIInfo(1);
	local _,HordeScore = GetWorldStateUIInfo(2);
	
	-- Warsong Gulch
	if (GetRealZoneText() == "Warsong Gulch") then
		-- 1 intensity
		if ((AllianceScore == "3/3" and HordeScore == "0/3") or 
			(AllianceScore == "0/3" and HordeScore == "3/3")) then
		--		DEFAULT_CHAT_FRAME:AddMessage("Intensity 1");
				return "1";
		end
	end	
	
	-- Bases: 0  Resources: 1000/2000
	if (GetRealZoneText() == "Arathi Basin") then
		-- Check the scores
		AllianceScore = tonumber(string.sub(AllianceScore,21,string.find(AllianceScore,"/") - 1));
		HordeScore = tonumber(string.sub(HordeScore,21,string.find(HordeScore,"/") - 1));
		
		-- 1 intensity
		if ((AllianceScore >= 1000 and HordeScore < 1000) or
		    (AllianceScore < 1000 and HordeScore >= 1000)) then
				return "1";
		end
	end
	
	-- 3 intensity	
	return "3";
	
end

-- This function will play an end game sound
function BGSoundAlerts_EndGameSound(msg)
	if (VictoryDefeatSounds == 1) then
		local SoundFile = WOW_DEF_DIR .. SoundsPack;
			
		if (BGSoundAlerts_PlayerWon(msg)) then
			-- Set Victory Sound
			SoundFile = SoundFile .. "\\Victory";
			-- Set Intensity
			SoundFile = SoundFile .. BGSoundAlerts_EndGameIntensity() .. ".wav";
		else
			-- Set Defeat Sound
			SoundFile = SoundFile .. "\\Defeat";
			-- Set Intensity
			SoundFile = SoundFile .. BGSoundAlerts_EndGameIntensity() .. ".wav";
		end
		
		BGSoundAlerts_AddToQueue(SoundFile);
		-- DEFAULT_CHAT_FRAME:AddMessage("Playing Sound");
	end
end

function BGSoundAlerts_IncomingSound(incmsg)
	
	if (IncomingSounds == 0) then
		return;
	end
	
	-- We will be building up a string to a sound dir according to the received message	
	local IncomingFile = WOW_DEF_DIR .. SoundsPack .. "\\";				-- The string to the sound dir
	
	-- Capitalize msg for easier parsing
	local msg = string.upper(incmsg);
	local begindigit, enddigit;
	
	-- Are we in a battleground
	if (GetRealZoneText() == "Warsong Gulch" or GetRealZoneText() == "Arathi Basin" 
		or GetRealZoneText() == "Alterac Valley") then
			
			-- Check for 'Inc'
			if (string.find(msg,"INC")) then
				IncomingFile = IncomingFile .. "Incoming";
				-- If Inc is found check for more detail
				-- Check for numbers
				begindigit, enddigit = string.find(msg,"(%d+)");
				-- Check for these if in Arathi Basin
				if (GetRealZoneText() == "Arathi Basin") then
					if (string.find(msg,"FARM")) then
						-- Inc Farm
						IncomingFile = IncomingFile .. "Farm";
					elseif (string.find(msg,"STABLES") or string.find(msg,"STAB")) then
						-- Inc Stables
						IncomingFile = IncomingFile .. "Stables";
					elseif (string.find(msg,"LM") or string.find(msg,"MILL") or string.find(msg,"LUMBER")) then
						-- Inc Lumbermill
						IncomingFile = IncomingFile .. "Lumbermill";
					elseif (string.find(msg,"GM") or string.find(msg,"MINE") or string.find(msg,"GOLD")) then
						-- Inc Gold Mine
						IncomingFile = IncomingFile .. "GoldMine";
					elseif (string.find(msg,"BS") or string.find(msg,"SMITH") or string.find(msg,"BLACK")) then
						-- Inc Blacksmith
						IncomingFile = IncomingFile .. "Blacksmith";
					elseif (string.find(msg,"BIG") or string.find(msg,"A(%s+)LOT") or string.find(msg,"MANY")) then
						-- Incoming Big
						IncomingFile = IncomingFile .. "Big";
					elseif (begindigit) then
						local number = tonumber(string.sub(msg,begindigit,enddigit));
						if (number <= 10 and number > 0) then
							-- Incoming Number
							IncomingFile = IncomingFile .. number;
						else
							-- Incoming Big
							IncomingFile = IncomingFile .. "Big";
						end
					end
				-- Check for these if in Warsong Gulch
				elseif (GetRealZoneText() == "Warsong Gulch") then
					if (string.find(msg,"BASE")) then
						-- Incoming Base
						IncomingFile = IncomingFile .. "Base";
					elseif (string.find(msg,"BIG") or string.find(msg,"A(%s+)LOT") or string.find(msg,"MANY")) then
						-- Incoming Big
						IncomingFile = IncomingFile .. "Big";
					elseif (begindigit) then
						local number = tonumber(string.sub(msg,begindigit,enddigit));
						if (number <= 10 and number > 0) then
							-- Incoming Number
							IncomingFile = IncomingFile .. number;
						else
							-- Incoming Big
							IncomingFile = IncomingFile .. "Big";
						end
					end
				-- Check for these if in Alterac Valley
				elseif (GetRealZoneText() == "Alterac Valley") then
					if (string.find(msg,"SF") or string.find(msg,"SNOW") or string.find(msg,"FALL")) then
						-- Incoming Snowfall Graveyard
						IncomingFile = IncomingFile .. "SnowfallGraveyard";
					elseif ((string.find(msg,"IB") or string.find(msg,"ICE(%s+)BLOOD")) and (string.find(msg,"GY") or string.find(msg,"GRAVE(%s+)YARD"))) then
						-- Incoming Iceblood Graveyard
						IncomingFile = IncomingFile .. "IcebloodGraveyard";
					elseif (string.find(msg,"IB") or string.find(msg,"ICE(%s+)BLOOD")) then
						-- Incoming Iceblood Tower
						IncomingFile = IncomingFile .. "IcebloodTower";
					elseif ((string.find(msg,"SH") or string.find(msg,"STONE(%s+)HEARTH")) and (string.find(msg,"BUNKER"))) then
						-- Incoming Stonehearth Bunker
						IncomingFile = IncomingFile .. "StonehearthBunker";
					elseif (string.find(msg,"SH") or string.find(msg,"STONE(%s+)HEARTH")) then
						-- Incoming Stonehearth Graveyard
						IncomingFile = IncomingFile .. "StonehearthGraveyard";
					elseif (((string.find(msg,"FW") or string.find(msg,"FROST(%s+)WOLF")) and (string.find(msg,"RELIEF(%s+)HUT") or string.find(msg,"RH")))
							or (string.find(msg,"RELIEF(%s+)HUT")) or (string.find(msg,"BASE(%s+)GY") and UnitFactionGroup("player") == "Horde")) then
						-- Incoming Frostwolf Relief Hut
						IncomingFile = IncomingFile .. "FrostwolfReliefHut";
					elseif (string.find(msg,"FW") or string.find(msg,"FROST(%s+)WOLF")) then
						-- Incoming Frostwolf Graveyard
						IncomingFile = IncomingFile .. "FrostwolfGraveyard";
					elseif (((string.find(msg,"SP") or string.find(msg,"STORM(%s+)PIKE")) and (string.find(msg,"AID(%s+)STATION") or string.find(msg,"AS")))
							or (string.find(msg,"AID(%s+)STATION")) or (string.find(msg,"BASE(%s+)GY") and UnitFactionGroup("player") == "Alliance")) then
						-- Incoming Stormpike Aid Station
						IncomingFile = IncomingFile .. "StormpikeAidStation";
					elseif (string.find(msg,"SP") or string.find(msg,"STORM(%s+)PIKE")) then
						-- Incoming Stormpike Graveyard
						IncomingFile = IncomingFile .. "StormpikeGraveyard";
					elseif (string.find(msg,"EAST") and string.find(msg,"TOWER")) then
						-- Incoming East Frostwolf Tower
						IncomingFile = IncomingFile .. "EastFrostwolfTower";
					elseif (string.find(msg,"WEST") and string.find(msg,"TOWER")) then
						-- Incoming West Frostwolf Tower
						IncomingFile = IncomingFile .. "WestFrostwolfTower";
					elseif (string.find(msg,"NORTH") and string.find(msg,"BUNKER")) then
						-- Incoming Dun Baldar North Bunker
						IncomingFile = IncomingFile .. "DunBaldarNorthBunker";
					elseif (string.find(msg,"SOUTH") and string.find(msg,"BUNKER")) then
						-- Incoming Dun Baldar South Bunker
						IncomingFile = IncomingFile .. "DunBaldarSouthBunker";
					elseif (string.find(msg,"BOSS") and UnitFactionGroup("player") == "Horde") then
						-- Incoming Drek'Thar
						IncomingFile = IncomingFile .. "DrekThar";
					elseif (string.find(msg,"BOSS") and UnitFactionGroup("player") == "Alliance") then
						-- Incoming Vanndar Stormpike
						IncomingFile = IncomingFile .. "VanndarStormpike";
					elseif (string.find(msg,"BIG") or string.find(msg,"A(%s+)LOT") or string.find(msg,"MANY")) then
						-- Incoming Big
						IncomingFile = IncomingFile .. "Big";
					elseif (begindigit) then
						local number = tonumber(string.sub(msg,begindigit,enddigit));
						if (number <= 10 and number > 0) then
							-- Incoming Number
							IncomingFile = IncomingFile .. number;
						else
							-- Incoming Big
							IncomingFile = IncomingFile .. "Big";
						end
					end
				
				
			end
			
			IncomingFile = IncomingFile .. ".wav";
				BGSoundAlerts_AddToQueue(IncomingFile);
		end
	end
end

function BGSoundAlerts_ShowPatchNotes()
	
	ShowUIPanel(BGSoundAlertsPatchNotes);
	
end