-- This is BGSoundAlerts Sound Engine
-- Keeps track of what is to play next and when
BGSoundAlerts_SoundQueue = { };
BGSoundAlerts_NextUpdate = 0.3;
BGSoundAlerts_ABGameTime = 0;

local IsInBG = 0;

-- Just to keep this file clean, the SoundLengths are in another file

function BGSoundAlerts_AddToQueue(file)
	-- This function will add file to the sound queue to be played
	-- If the sound could not be found in the sound lengths table then just play it
	local i;
	local filefoundlength;
	-- This is a table of soundlengths according to the selected SoundPack. DefaultPack = BGSoundAlerts_DefaultPackDurations
	if (SoundsPack == "DefaultPack") then
		local soundlengthtable = getglobal("BGSoundAlerts_" .. SoundsPack .. "Durations");
		
		for i = 1, table.getn(soundlengthtable) do
			if (soundlengthtable[i].dir == file) then
				filefoundlength = soundlengthtable[i].duration;
			end
		end
		
		if (filefoundlength) then
			local temptable = {
				dir = file,
				length = filefoundlength
				};
			
			-- Insert the sound into the queue
			table.insert(BGSoundAlerts_SoundQueue,temptable);
		else
			-- Not in the sound table so just play it
			PlaySoundFile(file);
		end
	else	
		-- We've got lengths for DefaultPack. If that's not selected just play it
		PlaySoundFile(file);
	end
end

function BGSoundAlerts_ClearSoundQueue()
	-- This function will clear all the sound queue
	-- This is used for example in the end of a battle where you no longer need to hear any more announcements
	local i;
	
	for i = table.getn(BGSoundAlerts_SoundQueue), 1 do
		table.remove(BGSoundAlerts_SoundQueue,i);
	end
end

function BGSoundAlerts_PlayNextSound()
	-- This function will play the next sound in the queue and return how long that sound will play
	-- If there is no sound in the queue it will just return 0.3
	if (BGSoundAlerts_SoundInQueue()) then
		local x;
		
		PlaySoundFile(BGSoundAlerts_SoundQueue[1].dir);
		x = BGSoundAlerts_SoundQueue[1].length;
		table.remove(BGSoundAlerts_SoundQueue,1);
		return x;
	else
		return 0.3;
	end
end

function BGSoundAlerts_SoundInQueue()
	-- This function will return 1 if there is a sound in the queue, nil otherwise
	if (table.getn(BGSoundAlerts_SoundQueue) > 0) then
		return 1;
	else
		return nil;
	end
end

function BGSoundAlerts_UpdateSoundEngine(elapsed)
	this.TimeSinceLastUpdate = this.TimeSinceLastUpdate + elapsed; 	
	while (this.TimeSinceLastUpdate > BGSoundAlerts_NextUpdate) do
		this.TimeSinceLastUpdate = this.TimeSinceLastUpdate - BGSoundAlerts_NextUpdate;
		BGSoundAlerts_NextUpdate = BGSoundAlerts_PlayNextSound();
	end
end

function BGSoundAlerts_UpdateABScore(elapsed)
	-- This should happen only in Arathi Basin
	if (GetRealZoneText() == "Arathi Basin" and ABScore == 1) then
		this.TimeSinceLastUpdate = this.TimeSinceLastUpdate + elapsed;
		while (this.TimeSinceLastUpdate > ABScoreDelay * 60) do
			BGSoundAlerts_ABGameTime = BGSoundAlerts_ABGameTime + ABScoreDelay;
			if (SoundsPack == "DefaultPack") then
				-- Work out the BG elapsed time
				BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\After.wav");
				-- This piece is a bit dirty but I didn't feel like it :P
				if (string.len(tostring(BGSoundAlerts_ABGameTime)) == 3) then
					BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\" ..
						string.sub(tostring(BGSoundAlerts_ABGameTime),1,1) .. "00.wav");
					BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\" ..	
						string.sub(tostring(BGSoundAlerts_ABGameTime),2,2) .. "0.wav");
					BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\" ..
						string.sub(tostring(BGSoundAlerts_ABGameTime),3,3) .. ".wav");
				elseif (string.len(tostring(BGSoundAlerts_ABGameTime)) == 2) then
					BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\" ..
						string.sub(tostring(BGSoundAlerts_ABGameTime),1,1) .. "0.wav");
					BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\" ..
						string.sub(tostring(BGSoundAlerts_ABGameTime),2,2) .. ".wav");
				elseif (string.len(tostring(BGSoundAlerts_ABGameTime)) == 1) then
					BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\" ..
						string.sub(tostring(BGSoundAlerts_ABGameTime),1,1) .. ".wav");
				end
				BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\MinutesArathiBasin.wav");
				
				local _,AllianceScore = GetWorldStateUIInfo(1);
				local _,HordeScore = GetWorldStateUIInfo(2);
				
				AllianceScore = tonumber(string.sub(AllianceScore,21,string.find(AllianceScore,"/") - 1));
				HordeScore = tonumber(string.sub(HordeScore,21,string.find(HordeScore,"/") - 1));
				
				-- See who's in the lead
				if (AllianceScore > HordeScore) then
						BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\Alliance.wav");
				elseif (AllianceScore <= HordeScore) then
						BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\Horde.wav");
				end
				
				BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\InTheLead.wav");
				
				-- Convert back to string
				AllianceScore = tostring(AllianceScore);
				HordeScore = tostring(HordeScore);
				
				-- Here comes the important bit
				
				BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\Alliance.wav");
				
				-- 234
				
				
				local i, x;
				for i = 1, string.len(AllianceScore) do
					local file = "Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\" .. string.sub(AllianceScore,i,i);
					for x = string.len(AllianceScore) - 1, i, -1 do
						file = file .. "0";						-- Add 0s
					end
					file = file .. ".wav";
					BGSoundAlerts_AddToQueue(file);
				end
				
				BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\Resources.wav");
				BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\And.wav");
				BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\Horde.wav");
				
				for i = 1, string.len(HordeScore) do
					local file = "Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\" .. string.sub(HordeScore,i,i);
					for x = string.len(HordeScore) - 1, i, -1 do
						file = file .. "0";						-- Add 0s
					end
					file = file .. ".wav";
					BGSoundAlerts_AddToQueue(file);
				end
				
				BGSoundAlerts_AddToQueue("Interface\\AddOns\\BGSoundAlerts\\DefaultPack\\Resources.wav");
			end
			this.TimeSinceLastUpdate = this.TimeSinceLastUpdate - ABScoreDelay * 60;
		end
	else
		BGSoundAlerts_ABGameTime = 0;
	end
end
			